@@ -3,7 +3,7 @@ use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.15";
+our $VERSION = "0.16";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
@@ -366,12 +366,19 @@ sub quote {
 
 sub historicals {
     my $self = ref $_[0] ? shift : ();    # might be undef but that's okay
-    my ($symbol, $interval, $span) = @_;
+    my ($symbol, $interval, $span, $bounds) = @_;
+    my %fields = (interval => $interval,
+                  span     => $span,
+                  bounds   => $bounds
+    );
+    my $fields = join '&', map { $_ . '=' . $fields{$_} }
+        grep { defined $fields{$_} } keys %fields;
     my ($status, $data, $raw)
         = _send_request($self,
                         'GET',
                         Finance::Robinhood::endpoint('quotes/historicals')
-                            . "$symbol/?interval=$interval&span=$span"
+                            . "$symbol/"
+                            . ($fields ? "?$fields" : '')
         );
     return if $status != 200;
     for (@{$data->{historicals}}) {
@@ -610,17 +617,24 @@ sub _send_request {
 # Coerce ISO 8601-ish strings into Time::Piece or DateTime objects
 sub _2_datetime {
     return if !$_[0];
+    $_[0]
+        =~ m[(\d{4})-(\d\d)-(\d\d)(?:T(\d\d):(\d\d):(\d\d)(?:\.(\d+))?(.+))?];
     if ($DEV && !defined $Time::Piece::VERSION)
     {    # We lose millisecond timestamps but gain speed!
         require Time::Piece;
     }
     if ($Time::Piece::VERSION) {
-        $_[0] =~ s[\..*][];
-        return Time::Piece->strptime($_[0], '%Y-%m-%dT%H:%M:%S');
+        my @vals = Time::Piece::_mini_mktime(
+            (defined $6 ? $6 : 0),    # second
+            (defined $5 ? $5 : 0),    # minute
+            (defined $4 ? $4 : 0),    # hour
+            $3 - 1,                   # day
+            $2 - 1,                   # month
+            $1 - 1900                 # year
+        );
+        return scalar Time::Piece->_mktime(\@vals, (defined $8 ? $8 : ()));
     }
     require DateTime;
-    $_[0]
-        =~ m[(\d{4})-(\d\d)-(\d\d)(?:T(\d\d):(\d\d):(\d\d)(?:\.(\d+))?(.+))?];
     DateTime->new(year  => $1,
                   month => $2,
                   day   => $3,
@@ -976,11 +990,12 @@ form does not require an account and may be called without ever logging in.
 
 You may retrieve historical quote data with this method. The first argument is
 a symbol. The second is an interval time and must be either C<5minute>,
-C<10minute>, C<day>, or C<week>.
+C<10minute>, C<day>, or C<week>. The third argument is a span of time
+indicating how far into the past you would like to retrieve and may be one of
+the following: C<day>, C<week>, C<year>, C<5year>, or C<all>. The fourth is a
+bounds which is one of the following: C<extended>, C<regular>, C<trading>.
 
-The third argument is a span of time indicating how far into the past you
-would like to retrieve and may be one of the following: C<day>, C<week>,
-C<year>, or C<5year>.
+All are optional and may be filled with an undefined value.
 
 So, to get five years of weekly historical data for Apple, you would write...
 
